@@ -64,7 +64,7 @@ class PenStyleWindow(QtWidgets.QDialog):
         self.penStyle = parent.canvas.penStyle
         
         # Import .ui forms for the GUI using function resource_path()
-        self.penOptionForm = self.resource_path("enhancedlabelme/ui/penstylewindow.ui")
+        # self.penOptionForm = self.resource_path("enhancedlabelme/ui/penstylewindow.ui")
         self.initUI(parent)
 
     # Define function to import external files when using PyInstaller.
@@ -80,9 +80,9 @@ class PenStyleWindow(QtWidgets.QDialog):
 
 
     def initUI(self, parent):
-        # option_ui = 'enhancedlabelme/ui/penstylewindow.ui'
-        # uic.loadUi(option_ui, self)
-        uic.loadUi(self.penOptionForm, self)
+        option_ui = osp.join(osp.dirname(osp.realpath(__file__)), 'ui/penstylewindow.ui')
+        uic.loadUi(option_ui, self)
+        # uic.loadUi(self.penOptionForm, self)
         
         # Load current style
         self.horizontalSlider_thickness.setSliderPosition(self.penThickness * 10)
@@ -994,11 +994,11 @@ class MainWindow(QtWidgets.QMainWindow):
     def readme(self):
         import platform, subprocess
         if platform.system() == 'Darwin':       # macOS
-            subprocess.call(('open', 'README.md'))
+            subprocess.call(('open', osp.join(osp.dirname(osp.realpath(__file__)), 'README.md')))
         elif platform.system() == 'Windows':    # Windows
-            subprocess.call(('notepad.exe', 'README.md'))
+            subprocess.call(('notepad.exe', osp.join(osp.dirname(osp.realpath(__file__)), 'README.md')))
         else:                                   # linux variants
-            subprocess.call(('xdg-open', 'README.md'))
+            subprocess.call(('xdg-open', osp.join(osp.dirname(osp.realpath(__file__)), 'README.md')))
             
     def checkUpdate(self):
         def compare(left, right):
